package com.jqtx.windows.job;

import com.jqtx.windows.component.LoanPlanComponent;
import com.jqtx.windows.component.OverduedComponent;
import com.jqtx.windows.component.enums.OverDuedTypeEnum;
import com.jqtx.windows.component.model.LoanPlanModel;
import com.jqtx.windows.component.model.OverduedModel;
import com.jqtx.windows.repository.entity.WindowsOverdued;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

@Component
@Slf4j
public class OevrduedJob {

    @Autowired
    private LoanPlanComponent loanPlanComponent;

    @Autowired
    private OverduedComponent overduedComponent;

    @XxlJob("oevrduedJob")
    public void run() {
        List<LoanPlanModel> planModels = loanPlanComponent.getWillOverdueList();
        //年月日时间
        LocalDate localDate = LocalDate.now();
        LocalDateTime localDateTime = LocalDateTime.now();
        //年月日时分秒时间
        planModels.forEach(e -> {
            OverduedModel windowsOverdued = getWindowsOverdued(e, localDate, localDateTime);
            overduedComponent.insert(windowsOverdued);
        });
    }


    private OverduedModel getWindowsOverdued(LoanPlanModel loanPlanModel, LocalDate localDate, LocalDateTime localDateTime) {
        OverduedModel model = new OverduedModel();
        model.setLoanNo(loanPlanModel.getLoanNo());
        model.setPlanNo(loanPlanModel.getPlanNo());
        model.setRemainBen(loanPlanModel.getPlanBen().subtract(loanPlanModel.getBackedBen()));
        model.setRemainXi(loanPlanModel.getPlanXi().subtract(loanPlanModel.getBackedXi()));
        model.setRemainFu(loanPlanModel.getPlanFu().subtract(loanPlanModel.getBackedFu()));
        model.setRemainFa(loanPlanModel.getPlanFa().subtract(loanPlanModel.getBackedFa()));
        model.setRemainBurden(loanPlanModel.getPlanBurden().subtract(loanPlanModel.getBackedBurden()));
        model.setRemianSpeaccount(loanPlanModel.getPlanSpeaccount().subtract(loanPlanModel.getBackedSpeaccount()));
        model.setRemainAmt(model.getRemainBen().add(model.getRemainXi()).add(model.getRemainFu())
                .add(model.getRemainFa()).add(model.getRemainBurden()).add(model.getRemianSpeaccount()));
        model.setOverDate(localDate);
        model.setStatus(OverDuedTypeEnum.OVERDUED.getCode());
        model.setGmtCreated(localDateTime);
        model.setGmtModified(localDateTime);
        return model;
    }
}
